#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: torrent
version: 10000.0.0
id: torrent-10000.0.0-22d396c73795880439a6e82530d1b742
key: torre_AhmdbG4GmgI9bVJu9sVuBx
license: BSD3
copyright: 2005-2007, Lemmih
maintainer: Joey Hess <id@joeyh.name>
synopsis: BitTorrent file parser and generater
category: Network
author: Lemmih <lemmih@gmail.com>
exposed: True
exposed-modules:
    Data.Torrent Data.Torrent.Scrape
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/torrent-10000.0.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/torrent-10000.0.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/torrent-10000.0.0
hs-libraries: HStorrent-10000.0.0-AhmdbG4GmgI9bVJu9sVuBx
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bencode-0.6.0.0-c722506d223e39dcc0fc13ef7118e4dd
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
haddock-interfaces: /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html: /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
